#
# spec file for package python-podman
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-podman%{psuffix}
Version:        5.3.0
Release:        1.2
Summary:        A library to interact with a Podman server
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/containers/podman-py
Source:         https://github.com/containers/podman-py/archive/refs/tags/v%{version}.tar.gz#./podman-%{version}.tar.gz
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module tomli >= 1.2.3 if python-base < 3.11}
BuildRequires:  %{python_module requests >= 2.24}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-tomli >= 1.2.3 if python-base < 3.11)
Requires:       python-requests
Requires:       python-urllib3
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module fixtures}
BuildRequires:  %{python_module podman >= %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module setuptools >= 39}
%if %{defined sle_version}
BuildRequires:  %{python_module dataclasses}
%endif
# /SECTION
%endif
%python_subpackages

%description
A library to interact with a Podman server

%prep
%autosetup -n podman-py-%{version}

%build
%pyproject_wheel

%if !%{with test}
%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%{python_expand $python -m pytest podman/tests/unit}
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/podman/
%{python_sitelib}/podman-%{version}.dist-info/
%endif

%changelog
* Tue Nov 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.3.0:
  * [skip-ci] Packit: downstream_package_name for each package key
    by @lsm5 in #416
  * Make "images.push" method support "format" parameter by
    @milanbalazs in #415
  * Add test of container create with DNS option by @Honny1 in #417
  * Fix podman search flake + update CI VM images by @cevich in
    [#418]
  * Update dependency containers/automation_images to v20240529 by
    @renovate in #389
  * Remove wait condition in run() by @inknos in #428
  * Update dependency containers/automation_images to v20240821 by
    @renovate in #423
  * domain/networks_manager.py: use specified driver in IPAMConfig
    by @jtluka in #429
  * Fix/Disable Pylint R0917 by @inknos in #432
  * Extend the parameters of 'images.load' and 'login' methods by
    @milanbalazs in #434
  * Don't use root as default user for exec_run by @aparcar in #431
  * Renovate: Update default assignment by @cevich in #437
  * Packit: enable c9s downstream update by @lsm5 in #440
  * Audit and Update OWNERS file by @baude in #441
  * Update dependency ubuntu to v24 by @renovate in #436
  * Remove the container in case of detach mode by @milanbalazs in
    [#435]
  * Update CI VM images by @inknos in #430
  * Fix cyclic-import by @Honny1 in #450
  * Packit: constrain koji and bodhi jobs to fedora package by
    @lsm5 in #442
  * Fix default stderr value of container.logs() to match
    documentation. by @MattBelle in #452
  * [skip-ci] RPM: remove conditionals from changelog by @lsm5 in
    [#453]
  * Added stream support to Container.exec_run(). by @MattBelle in
    [#454]
  * Accept integer ports in containers_create.create by @krrhodes
    in #447
  * Container.labels now returns an empty dict instead of None. by
    @MattBelle in #462
  * Fix typos by @kianmeng in #464
  * fix[docs]: Unindented example code on the index page by
    @Mr-Sunglasses in #467
  * Added support for mounting directories through the volume
    keyword. by @MattBelle in #460
  * docs: Add Installation and docs in README.md by @Mr-Sunglasses
    in #471
  * fix: name filter in images.list() by @Mr-Sunglasses in #468
  * Bump release to 5.3.0 and drop python<3.8 by @inknos in #469
* Fri Aug  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.2.0:
  * Fix the TypeError exception in the images.prune method by
    @milanbalazs in #412
  * Bump version to 5.2.0 by @inknos in #414
* Fri Aug  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.1.0:
  * Fix dns_option typo by @robbmanes in #386
  * Fixes encoding of X-Registry-auth HTTP Header value from Base64
    to url_safe Base64 by @apozsuse in #385
  * Include py.typed marker file. by @jonded94 in #381
  * [skip-ci] Packit: enable c10s downstream sync by @lsm5 in #388
  * ignore proxies from the env vars when using UNIX Domain Sockets
    by @eighthave in #391
  * Fix Pylint E0606 for undefined variable after else by @inknos
    in #392
  * [skip-ci] Packit: use default update_release behavior by @lsm5
    in #393
  * Update OWNERS by @jwhonce in #394
  * Fix README TypeError when one container is running by @inknos
    in #395
  * Remove Fedora release number from task names by @cevich in #396
  * Add python 3.12 support and remove python xdg by @inknos in
    [#401]
  * Update index.rst Client -> PodmanClient by @jwoehr in #405
  * Implementing the functionality of the 'named' argument of the
    'Image.save' method by @milanbalazs in #406
  * Fix the locally non-existent image fails with AttributeError by
    @milanbalazs in #408
  * Enable demux option in exec_run by @inknos in #410
  * Bump version to 5.1.0 by @inknos in #409
* Sat Mar 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.0.0:
  * Bump main to 5.0.0-dev by @umohnani8 in #369
  * Add workdir as alias for working_dir by @umohnani8 in #368
  * from_env: Use default base_url if no environment is given by
    @kajinamit in #372
  * chore(deps): update dependency containers/automation_images to
    v20240125 by @renovate in #373
  * Use new json connections file by @umohnani8 in #374
  * Remove deprecated max_pools_size arg by @umohnani8 in #375
  * Use volumes param for container rm by @umohnani8 in #376
  * [skip-ci] Update tim-actions/get-pr-commits action to v1.3.1 by
    @renovate in #377
  * chore(deps): update dependency containers/automation_images to
    v20240320 by @renovate in #383
  * Bump version to 5.0.0 by @umohnani8 in #382
* Tue Jan 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
-  update to 4.9.0:
  * Add rich dep to setup.cfg by @umohnani8 in
    https://github.com/containers/podman-py/pull/353
  * Fix lint issues by @umohnani8 in
    https://github.com/containers/podman-py/pull/358
  * Update dependency containers/automation_images to v20231208 by
    @renovate in https://github.com/containers/podman-py/pull/355
  * Bump main to 4.9.0-dev by @umohnani8 in
    https://github.com/containers/podman-py/pull/348
  * Make progress_bar an extra feature by @yselkowitz in
    https://github.com/containers/podman-py/pull/361
  * Enable user defined netns by @dcasier in
    https://github.com/containers/podman-py/pull/364
  * Update dependency containers/automation_images to v20240102 by
    @renovate in https://github.com/containers/podman-py/pull/365
  * Fix the 'max_pool_size' parameter passing for Adapters by
    @milanbalazs in
    https://github.com/containers/podman-py/pull/366
  * Bump version to v4.9 by @umohnani8 in
    https://github.com/containers/podman-py/pull/367
* Tue Jan 16 2024 Dan Čermák <dcermak@suse.com>
- Remove unneeded BuildRequires for test package
* Sun Jan  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 4.8.1:
  * [release-4.8] Make progress_bar an extra feature by
    @openshift-cherrypick-robot in
    https://github.com/containers/podman-py/pull/362
  * Bump version to 4.8.2 by @umohnani8 in
    https://github.com/containers/podman-py/pull/363
* Thu Dec 21 2023 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 4.8.1:
  * [release-4.8] Add rich dep to setup.cfg by
    @openshift-cherrypick-robot in #354
  * [release-4.8] Fix lint issues by @openshift-cherrypick-robot in
    [#359]
  * Bump version to podman 4.8.1 by @umohnani8 in #357
* Tue Nov 28 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.8.0:
  * Update version to 4.8.0-dev by @umohnani8 in #329
  * Fix up docs and format issues by @umohnani8 in #338
  * Fix readthedocs yaml by @umohnani8 in #339
  * Add progress_bar option to image pull by @umohnani8 in #340
  * Update dependency containers/automation_images to v20231004 by
    @renovate in #335
  * Update pull progress bar colour by @umohnani8 in #341
  * Fix readthedocs build issues by @umohnani8 in #342
  * Update dependency containers/automation_images to v20231116 by
    @renovate in #344
  * Bump version v4.8.0 by @umohnani8 in #345
* Thu Sep 28 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.6.0:
  * Bump version to v4.6.0 by @umohnani8 in #303
  * Packit: mention downstream_package_name: python-podman in
    config by @lsm5 in #306
  * Bump version on main to 4.7.0-dev by @umohnani8 in #304
  * Add read_write_tmpfs by @msisj in #302
  * Update dependency containers/automation_images to v20230807 by
    @renovate in #308
  * remove direct logging to sys.stderr by @chnrxn in #311
  * packit: Build PRs into default packit COPRs by @martinpitt in
    [#310]
  * Update dependency ubuntu to v22 by @renovate in #313
  * Update dependency containers/automation_images to v20230809 by
    @renovate in #314
  * [skip-ci] Update tim-actions/commit-message-checker-with-regex
    action to v0.3.2 by @renovate in #317
  * Fix assertation error in manifest.py by @umohnani8 in #320
  * Update dependency containers/automation_images to v20230816 by
    @renovate in #316
  * Fixes the secrets parameter, adds the secret_env parameter by
    @andryyy in #319
  * Fix image SCP when not providing quiet by @hpvb in #321
  * Change default value for tty in exec_run by @maxi0604 in #324
* Mon Jul 24 2023 Johannes Kastl <kastl@b1-systems.de>
- use new Build macros
- update constraints on BuildRequires
  * drop constraint for urllib3 < 2
  * add constraint on requests and pyxdg
- follow upstream and use new tomli (for python < 3.11) instead of
  pytoml
* Mon Jul 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.6.0:
  * Bump version to 4.5.0 by @umohnani8 in #263
  * chore(deps): update dependency containers/automation_images to
    v20230426 by @renovate in #259
  * chore(deps): update dependency urllib3 to v2 by @renovate in
    [#265]
  * [skip-ci] Update tim-actions/get-pr-commits action to v1.3.0 by
    @renovate in #268
  * chore(deps): update dependency containers/automation_images to
    v20230517 by @renovate in #270
  * Streaming support for PodsManager.stats API by @RazCrimson in
    [#266]
  * Minor text fixes in contributing.md by @umohnani8 in #278
  * Swap renovate dep. update. PR assignments by @cevich in #279
  * chore(deps): update dependency containers/automation_images to
    v20230601 by @renovate in #280
  * Update Makefile to emulate readthedocs automation by @umohnani8
    in #282
  * [CI:BUILD] Packit: initial enablement by @lsm5 in #242
  * chore(deps): update dependency containers/automation_images to
    v20230614 by @renovate in #286
  * Packit: remove .packit.sh by @lsm5 in #288
  * Fix catching errors in the response body of containers/prune by
    @francisbergin in #290
  * Fix pod prune error explanation string by @francisbergin in
    [#291]
  * Refactor Makefile to support tox / MacOS Ventura by @jwhonce in
    [#285]
  * Switch HTTPConnection from http.client to urllib3.connection by
    @dcermak in #283
  * Keep main branch version ahead of release branches by @lsm5 in
    [#289]
  * [CI:BUILD] RPM: Cleanup by @lsm5 in #296
  * Includes the possibility to use the 'listTags' parameter in
    image search endpoint by @apozsuse in #295
  * Update dependency fixtures to ~=4.1.0 by @renovate in #297
  * Update fixtures to not be tied to a version by @umohnani8 in
    [#300]
  * Fix passing filters to networks prune by @francisbergin in #298
* Sat Jun  3 2023 Georg Pfuetzenreuter <georg.pfuetzenreuter@suse.com>
- Require pytoml
* Thu Jun  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 4.5.1:
  * [v4.5-rhel] cherry-pick urlib3 fixes by @umohnani8 in
    https://github.com/containers/podman-py/pull/274
* Fri Apr 28 2023 Johannes Kastl <kastl@b1-systems.de>
- add necessary Requires, remove outdated Requires
- add _service file
  - change URL to make `osc service disabledrun download_files`
    work
- update to 4.5.0:
  * Change docstring to point to podman docs
  * [skip-ci] Update tim-actions/get-pr-commits action to v1.2.0
  * Add renovate.json
  * Fix new lint problems
  * Improve exception when missing env var
  * chg: Container.top to use stream_helper
  * chg: Container.stats to use stream_helper
  * add: stream_helper in api/parse_utils.py
  * Cirrus: Update CI VM images
  * Bump fixtures requirement
  * Specify version verbatim in setup.cfg
  * [spec] Switch license to SPDX
  * podman.spec: run unit tests
  * Fix version spec in setup.cfg
  * Correct pyproject.toml [build-system] requires
  * Fallback to pytoml on RHEL 8 and toml on 9
  * Use modern tomllib/tomli modules for reading TOML files
  * Revert "Use modern tomllib/tomli modules for reading TOML
    files"
  * chore: Container.stats - type hints
  * fix: Container.stats - invalid response for non-stream mode
  * fix: Container.stats - missing stream param to requests
  * Lint fix
  * Merge branch 'containers:main' into
    feat/container-create-secret
  * Correctly add secrets to container on creation
* Fri Feb 24 2023 Dan Čermák <dcermak@suse.com>
- cleanup requires & suggests (fixes boo#1208627)
- New upstream release 4.4.1:
    This release contains necessary backports to revert the new tomli package
    that was introduced but is not supported by RHEL currently.
- New upstream release 4.4.0:
    Bump version to 4.3.0 by @umohnani8 in #216
    update urllib to 1.26.5 for a CVE found in previous versions by @cdoern in #210
    Correct path for rtd conf.py by @baude in #219
    Clean up pylint configuration by @jwhonce in #222
    Use modern tomllib/tomli modules for reading TOML files by @mgorny in #214
    Added port binding range by @msisj in #224
    Update cirrus image by @rhatdan in #225
    Cirrus: Update CI VM images to F37 by @cevich in #228
    Fix the ability to run containers by @jonathanunderwood in #226
    Update files to adhere to new lint requirements by @umohnani8 in #236
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 4.3.0
  * Add pass-through layers, output and outputformat to building images
  * Support passing of interval and condition in podman wait calls
  * Implement podman image scp
  * Update supported python versions
  * Add support of passing empty strings in second
  * Add support for on failure actions in healthchecks
  * Bug fixes
* Mon Aug 15 2022 Michael Ströder <michael@stroeder.com>
- update to 4.2.0
  * Added support for devices in container creation
  * Implemented the login endpoint
  * Added relabel option for mounts and other mount option support
  * Implemented exec_run
  * Bug Fixes
* Thu Jun 30 2022 Johannes Kastl <kastl@b1-systems.de>
- update to 4.0.0
  * Remove support for old (ApiConnection) API
  * Update CI to use copr and release podman packages for testing
  * Port code to support Podman 4.0.0 API changes
  * Added support for Python 3.10
  * lint scrub and correction of code
  * Bug fixes
  * Move to tox for development support
  * Move to pytest from nose for test execution
  * Support testing python 3.6,3.8-3.10
  * Allow passing string values to memory limits
- remove patch python310.patch
* Wed Jun 29 2022 Johannes Kastl <kastl@b1-systems.de>
- disable building for python2
* Mon Feb 21 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * Update packaging
  * Update CI to support testing against released and main podman branches
  * Cleanup CI configuration
  * Bug fixes
  * Bug fixes and updates to make API more complete
  * Update dependency checking
  * PodmanClient() now supports service addresses using ssh:// and tcp://
    schemes. The keyword connection has been added, using its value as a key
    into the connections that have been defined in
    XDG_CONFIG_DIR/containers/containers.cfg. The podman system connection is
    used to curate connections.
  * docstrings were cleaned up to aid in future sphinx generated documentation.
  * ssh:// service addresses are supported by the use of an external ssh client.
  * tcp:// connections are not secure.
  * PodmanClient() introduces docker-py functionality, while additionally
    allowing access to Podman unique functionality such as Pods.
  * Note: APIConnection() and it's support classes will be deprecated.
- add python310.patch: support python 3.10
* Thu May 27 2021 pgajdos@suse.com
- %%check: run test via %%pyunittest rpm macro
* Fri Feb 21 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.6.0:
  * Update code and tests for changes in API
  * Introduce mocked unit tests
  * Refactor for changes in containers API
  * ModuleNotFoundError: No module named 'pbr'
  * Improve testing
  * Apply pep8 and clean code
  * remove redundant license file
  * How to install from pypi
- Correct BuildRequires.
- Drop unshipped file from %%license macro.
* Wed Aug 28 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 0.12.0)
